// @ts-check

require("dotenv").config();

/** @type {import('@docusaurus/types').Config} */
const config = {
	title: "Dead Network",
	tagline:
		"Мережа сервісів і платформ, які дають змогу окремим особам і спільнотам спілкуватися, ділитися та розвиватися разом.",
	url: "https://dead.guru",
	baseUrl: "/",
	onBrokenLinks: "throw",
	onBrokenMarkdownLinks: "warn",
	favicon: "design/web/favicon.ico",
	organizationName: "dead",
	projectName: "dead",
	themeConfig: /** @type {import('@docusaurus/preset-classic').ThemeConfig} */ {
		announcementBar: {
			id: "2_0",
			content:
				'🎉 Зя`вився XMPP сервер доєднатися можна <a href="/doc/xmpp">тут</a> 🎉',
		},
		docs: {
			sidebar: {
				autoCollapseCategories: true,
			},
		},
		navbar: {
			title: "Dead Network",
			hideOnScroll: true,
			logo: {
				alt: "Dead Logo",
				src: "img/logo.svg",
				srcDark: "img/logo-white.svg",
			},
			items: [
				{
					label: "Документація",
					to: "docs/introduction",
				},
				{
					label: "Клієнти",
					to: "downloads",
				},
				{
					label: "Інформація",
					position: "right",
					items: [
						{
							label: "Вступ",
							to: "docs/introduction",
						},
						{
							label: "Як почати",
							to: "docs/getting-started",
						},
						{
							label: "ЗІВі",
							to: "docs/faq",
						},
					],
				},
				{
					href: "https://git.dead.guru/DeadGuru/network",
					position: "right",
					className: "header-github-link",
					"aria-label": "GitHub Репозиторій",
				},
			],
		},
		footer: {
			copyright: `<a href="https://vercel.com/?utm_source=meshtastic&utm_campaign=oss">Powered by ▲ Vercel</a>.`,
		},
		colorMode: {
			respectPrefersColorScheme: true,
		},
		mermaid: {
			theme: { light: "base", dark: "base" },
			options: {
				themeVariables: {
					primaryColor: "#f03131",
					primaryTextColor: "var(--tw-prose-headings)",
					primaryBorderColor: "#4D4D4D",
					lineColor: "#EAD667",
					secondaryColor: "#EA67BD",
					tertiaryColor: "#677CEA",
				},
			},
		},
	},
	plugins: [
		() => {
			return {
				name: "docusaurus-tailwindcss",
				configurePostCss(postcssOptions) {
					postcssOptions.plugins.push(require("tailwindcss"));
					postcssOptions.plugins.push(require("autoprefixer"));
					return postcssOptions;
				},
			};
		},
	],
	presets: [
		[
			"@docusaurus/preset-classic",
			/** @type {import('@docusaurus/preset-classic').Options} */
			{
				docs: {
					sidebarPath: require.resolve("./sidebars.js"),
					editUrl: "https://github.com/dead/dead/edit/master/",
					breadcrumbs: false,
					showLastUpdateAuthor: true,
				},
				theme: {
					customCss: require.resolve("./src/css/custom.css"),
				},
			},
		],
	],
	customFields: {
		API_URL: process.env.API_URL,
	},
	markdown: {
		mermaid: true,
	},
	themes: ["@docusaurus/theme-mermaid"],
};

module.exports = config;
